/**
 * Interface to Apalache
 *
 * This functionality is enabled by managing and interacting with the Apalache
 * server.
 *
 * @author Shon Feder
 *
 * @module
 */
import { Either } from '@sweet-monads/either';
import { ErrorMessage } from './ErrorMessage';
import { ItfTrace } from './itf';
type ApalacheError = {
    explanation: string;
    errors: ErrorMessage[];
    traces?: ItfTrace[];
};
export type ApalacheResult<T> = Either<ApalacheError, T>;
type ApalacheConfig = any;
type Apalache = {
    check: (c: ApalacheConfig) => Promise<ApalacheResult<void>>;
    tla: (c: ApalacheConfig) => Promise<ApalacheResult<string>>;
};
/**
 * Connect to an already running Apalache server, or – if unsuccessful – fetch
 * Apalache, spawn it, and connect to it.
 *
 * If an Apalache server is spawned, the child process exits when the parent process (i.e., this process) terminates.
 *
 * @returns A promise resolving to:
 *    - a `right<Apalache>` equal to the path the Apalache dist was unpacked to,
 *    - a `left<ApalacheError>` indicating an error.
 */
export declare function connect(verbosityLevel: number): Promise<ApalacheResult<Apalache>>;
export {};
