import { QuintEx } from './ir/quintIr';
import { ExecutionFrame } from './runtime/trace';
import { IdGenerator } from './idGenerator';
import { Rng } from './rng';
import { SourceLookupPath } from './parsing/sourceResolver';
import { QuintError } from './quintError';
/**
 * Various settings that have to be passed to the simulator to run.
 */
export interface SimulatorOptions {
    init: string;
    step: string;
    invariant: string;
    maxSamples: number;
    maxSteps: number;
    rng: Rng;
    verbosity: number;
}
/** The outcome of a simulation
 */
export type Outcome = {
    status: 'ok';
} /** Simulation succeeded */ | {
    status: 'violation';
} /** Simulation found an invariant violation */ | {
    status: 'error';
    errors: QuintError[];
}; /** An error occurred during simulation  */
/**
 * A result returned by the simulator.
 */
export interface SimulatorResult {
    outcome: Outcome;
    vars: string[];
    states: QuintEx[];
    frames: ExecutionFrame[];
    seed: bigint;
}
/**
 * Execute a run.
 *
 * @param idGen a unique generator of identifiers
 * @param code the source code of the modules
 * @param mainStart the start index of the main module in the code
 * @param mainEnd the end index of the main module in the code
 * @param mainName the module that should be used as a state machine
 * @param mainPath the lookup path that was used to retrieve the main module
 * @param options simulator settings
 * @returns either error messages (left),
    or the trace as an expression (right)
 */
export declare function compileAndRun(idGen: IdGenerator, code: string, mainStart: number, mainEnd: number, mainName: string, mainPath: SourceLookupPath, options: SimulatorOptions): SimulatorResult;
