"use strict";
/* ----------------------------------------------------------------------------------
 * Copyright 2022 Informal Systems
 * Licensed under the Apache License, Version 2.0.
 * See LICENSE in the project root for license information.
 * --------------------------------------------------------------------------------- */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeInferrer = void 0;
const IRVisitor_1 = require("../ir/IRVisitor");
const constraintGenerator_1 = require("./constraintGenerator");
const constraintSolver_1 = require("./constraintSolver");
const simplification_1 = require("./simplification");
class TypeInferrer extends constraintGenerator_1.ConstraintGeneratorVisitor {
    constructor(table, types) {
        super(constraintSolver_1.solveConstraint, table, types);
    }
    /**
     * Infers a type for each expression in a list of QuintDeclarations
     *
     * @param declarations: the list of QuintDeclarations to infer types for
     *
     * @returns a map from expression ids to their type schemes and a map from expression
     *          ids to the corresponding error for any problematic expressions.
     */
    inferTypes(declarations) {
        // Resolve all type applications used in expressions in the lookup table
        declarations.forEach(decl => {
            (0, IRVisitor_1.walkDeclaration)(this, decl);
        });
        const simplifiedTypes = new Map([...this.types.entries()].map(([id, t]) => [id, (0, simplification_1.simplify)(t)]));
        return [this.errors, simplifiedTypes];
    }
}
exports.TypeInferrer = TypeInferrer;
//# sourceMappingURL=inferrer.js.map